@@ -593,6 +593,12 @@ open_calendar (ECalBackendSync *backend, EDataCal *cal,
 	e_folder_exchange_subscribe (E_CAL_BACKEND_EXCHANGE (backend)->folder,
 			E2K_CONTEXT_OBJECT_CHANGED, 30,
 			notify_changes, backend);
+        e_folder_exchange_subscribe (E_CAL_BACKEND_EXCHANGE (backend)->folder,
+			E2K_CONTEXT_OBJECT_ADDED, 30,
+			notify_changes, backend);
+        e_folder_exchange_subscribe (E_CAL_BACKEND_EXCHANGE (backend)->folder,
+			E2K_CONTEXT_OBJECT_REMOVED, 30,
+			notify_changes, backend);
 
 	thread = g_thread_create ((GThreadFunc) get_changed_events, E_CAL_BACKEND_EXCHANGE (backend), FALSE, &error);
 	if (!thread) {
@@ -602,6 +608,14 @@ open_calendar (ECalBackendSync *backend, EDataCal *cal,
 	}
 }
 
+static void
+refresh_calendar (ECalBackendSync *backend, EDataCal *cal, GError **perror)
+{
+	g_return_if_fail (E_IS_CAL_BACKEND_EXCHANGE (backend));
+
+	get_changed_events (E_CAL_BACKEND_EXCHANGE (backend));
+}
+
 struct _cb_data {
 	ECalBackendSync *be;
 	icalcomponent *vcal_comp;
@@ -2430,6 +2444,7 @@ class_init (ECalBackendExchangeCalendarClass *klass)
 	parent_class = g_type_class_peek_parent (klass);
 
 	sync_class->open_sync = open_calendar;
+	sync_class->refresh_sync = refresh_calendar;
 	sync_class->create_object_sync = create_object;
 	sync_class->modify_object_sync = modify_object;
 	sync_class->remove_object_sync = remove_object;
